summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/registersearchline.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/registersearchline.h')
-rw-r--r--kmymoney2/widgets/registersearchline.h22
1 files changed, 12 insertions, 10 deletions
diff --git a/kmymoney2/widgets/registersearchline.h b/kmymoney2/widgets/registersearchline.h
index d495ab1..e9fcb39 100644
--- a/kmymoney2/widgets/registersearchline.h
+++ b/kmymoney2/widgets/registersearchline.h
@@ -21,7 +21,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qhbox.h>
+#include <tqhbox.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -46,6 +46,7 @@ namespace KMyMoneyRegister {
class KMYMONEY_EXPORT RegisterSearchLine : public KLineEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructs a RegisterSearchLine with @a reg being the register to be
@@ -54,14 +55,14 @@ public:
* If @a reg is null then the widget will be disabled until a register
* is set with setRegister().
*/
- RegisterSearchLine(QWidget* parent = 0, Register* reg = 0, const char* name = 0);
+ RegisterSearchLine(TQWidget* tqparent = 0, Register* reg = 0, const char* name = 0);
/**
* Constructs a RegisterSearchLine
*
* The widget will be disabled until a register is set with setRegister().
*/
- RegisterSearchLine(QWidget* parent = 0, const char* name = 0);
+ RegisterSearchLine(TQWidget* tqparent = 0, const char* name = 0);
/**
* Destroys the object
@@ -77,14 +78,14 @@ public:
void setRegister(Register* reg);
protected:
- virtual bool itemMatches(const RegisterItem* item, const QString& s) const;
+ virtual bool itemMatches(const RegisterItem* item, const TQString& s) const;
public slots:
- virtual void updateSearch(const QString& s = QString::null);
+ virtual void updateSearch(const TQString& s = TQString());
virtual void reset(void);
protected slots:
- void queueSearch(const QString& search);
+ void queueSearch(const TQString& search);
void activateSearch(void);
void slotStatusChanged(int);
@@ -106,15 +107,16 @@ private:
*
* @author Thomas Baumgart
*/
-class KMYMONEY_EXPORT RegisterSearchLineWidget : public QHBox
+class KMYMONEY_EXPORT RegisterSearchLineWidget : public TQHBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Creates a RegisterSearchLineWidget for @a reg with @a parent as the
* parent and with @a name.
*/
- RegisterSearchLineWidget(Register* reg = 0, QWidget* parent = 0, const char* name = 0);
+ RegisterSearchLineWidget(Register* reg = 0, TQWidget* tqparent = 0, const char* name = 0);
/**
* Destroys the object
@@ -106,15 +107,16 @@ private:
public:
/**
- * Creates a RegisterSearchLineWidget for @a reg with @a parent as the
- * parent and with @a name.
+ * Creates a RegisterSearchLineWidget for @a reg with @a tqparent as the
+ * tqparent and with @a name.
*/